﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using C1.Silverlight.Schedule;
using C1.C1Schedule;

namespace C1Schedule_Sample
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            cmbView.Items.Add("Day");
            cmbView.Items.Add("WorkingWeek");
            cmbView.Items.Add("Week");
            cmbView.Items.Add("Month");
            cmbView.Items.Add("TimeLine");
            cmbView.SelectedIndex = 3;

            Appointment app = new Appointment(DateTime.Today.AddHours(12), TimeSpan.FromHours(1));
            app.Subject = "Progress Meeting";
            c1Scheduler1.DataStorage.AppointmentStorage.Appointments.Add(app);


            app = new Appointment(DateTime.Today.AddHours(14), TimeSpan.FromHours(3));
            app.Subject = "Product Meeting";
            app.Body = "A meeting about new products";
            c1Scheduler1.DataStorage.AppointmentStorage.Appointments.Add(app);

            app = new Appointment(DateTime.Today.AddHours(10), TimeSpan.FromMinutes(15));
            app.Subject = "Silverlight Study Session";
            c1Scheduler1.DataStorage.AppointmentStorage.Appointments.Add(app);

        }

        List<VisualIntervalPresenter> lst = new List<VisualIntervalPresenter>();

        private void SelectVisualInterval(Point point)
        {
            ClearVisualIntervals();

            Point location = point;
            lst.Clear();
            //Get the right clicked Interval and select it
            VisualIntervalPresenter el = GetUIElement(c1Scheduler1, location);

            if (el != null)
            {
                el.Interval.IsSelected = true;
                lst.Add(el);
            }
        }

        private void ClearVisualIntervals()
        {
            for (int i = 0; i < c1Scheduler1.GroupItems.Count; i++)
            {
                foreach (var vi in c1Scheduler1.GroupItems[i].VisualIntervals)
                {
                    vi.IsSelected = false;
                }
            }
        }

        public static VisualIntervalPresenter GetUIElement(C1Scheduler sched, Point location)
        {
            IEnumerable<UIElement> els;

            //Finds all elements in host coordinates and returns the matched VisualIntervalPresenter
            try
            {
                els = VisualTreeHelper.FindElementsInHostCoordinates(location, sched);
                foreach (UIElement el in els)
                {
                    if (el is VisualIntervalPresenter)
                    {
                        return (VisualIntervalPresenter)el;
                    }
                }
            }
            catch
            {
            }

            return null;
        }

        private void c1Scheduler1_MouseRightButtonDown(object sender, MouseButtonEventArgs e)
        {
            Point location = e.GetPosition(this);
            SelectVisualInterval(location);
        }

        private void c1Scheduler1_MouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            foreach (VisualIntervalPresenter vp in lst)
                if (vp.Interval != null)
                    vp.Interval.IsSelected = false;

            lst.Clear();

            if (c1Scheduler1.SelectedVisualInterval != null)
                c1Scheduler1.SelectedVisualInterval.IsSelected = true;
        }

        private void cmbView_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            switch ((string)cmbView.SelectedItem)
            {
                case "Month":
                    c1Scheduler1.ChangeStyle(c1Scheduler1.MonthStyle);
                    break;
                case "Day":
                    c1Scheduler1.ChangeStyle(c1Scheduler1.OneDayStyle);
                    break;
                case "WorkingWeek":
                    c1Scheduler1.ChangeStyle(c1Scheduler1.WorkingWeekStyle);
                    break;
                case "Week":
                    c1Scheduler1.ChangeStyle(c1Scheduler1.WeekStyle);
                    break;
                case "TimeLine":
                    c1Scheduler1.ChangeStyle(c1Scheduler1.TimeLineStyle);
                    break;
            }
        }

        private void c1Scheduler1_StyleChanged(object sender, RoutedEventArgs e)
        {
            if (c1Scheduler1.Style == c1Scheduler1.WorkingWeekStyle)
            {
                cmbView.SelectedIndex = 1;
            }
            else if (c1Scheduler1.Style == c1Scheduler1.WeekStyle)
            {
                cmbView.SelectedIndex = 2;
            }
            else if (c1Scheduler1.Style == c1Scheduler1.MonthStyle)
            {
                cmbView.SelectedIndex = 3;
            }
            else if (c1Scheduler1.Style == c1Scheduler1.TimeLineStyle)
            {
                cmbView.SelectedIndex = 4;
            }
            else
            {
                cmbView.SelectedIndex = 0;
            }
        }
    }
}
